@@ -24,7 +24,6 @@ class QLDBDriver:
 
 
     def execute(self, transaction_executor, statement):
-        syslog.syslog(f"CARGOPRODUCE: {statement}")
         cursor = transaction_executor.execute_statement(statement)
         
         return cursor
@@ -147,6 +146,13 @@ class QLDBDriver:
     def insert_many(self, table_name, data, step = 40):
         raw_data = data
 
+        for i in range(len(data)):
+            for key, value in data[i].items():
+                try:
+                    data[i][key] = data[i][key].replace("'", "")
+                except:
+                    pass
+
         while len(raw_data) > 0:
             data_tmp = str(raw_data[:step]).replace("None", "null")
 
@@ -154,6 +160,8 @@ class QLDBDriver:
 
             statement = f"INSERT INTO {table_name} << {data_tmp} >>"
 
+            syslog.syslog(statement + " \n")
+
             self.execute_statement(statement)
 
             del raw_data[:step]
